@@ -231,8 +231,8 @@ sfInit <- function( parallel=NULL,
 
     ## @TODO Exception handler.
     ## @TODO Timeout on init.
-    ## Ebenso: Timeout - das ist extrem hsslich, wenn das Cluster nicht
-    ## korrekt startet und hngen bleibt (z.B. wenn zuviele CPUs fr das
+    ## Ebenso: Timeout - das ist extrem hässlich, wenn das Cluster nicht
+    ## korrekt startet und hängen bleibt (z.B. wenn zuviele CPUs für das
     ## Cluster angefordert werden - was PVM schluckt, macht MPI anscheinend
     ## Kopfzerbrechen).
     setDefaultClusterOptions( type = .sfOption$type )
@@ -259,20 +259,20 @@ sfInit <- function( parallel=NULL,
       setOption( "cluster", try( makeCluster( .sfOption$nodes,
                                               outfile = tmp ) ) )
     }
-    # Network Spaces
-    else if( .sfOption$type == "NWS" ) {
-      if( is.null( .sfOption$sockHosts ) || ( length( .sfOption$sockHosts ) == 0 ) )
-        setOption( "sockHosts", c( rep( "localhost", .sfOption$nodes ) ) )
-      else
-        setOption( "nodes", length( .sfOption$sockHosts ) )
+    ## # Network Spaces
+    ## else if( .sfOption$type == "NWS" ) {
+    ##   if( is.null( .sfOption$sockHosts ) || ( length( .sfOption$sockHosts ) == 0 ) )
+    ##     setOption( "sockHosts", c( rep( "localhost", .sfOption$nodes ) ) )
+    ##   else
+    ##     setOption( "nodes", length( .sfOption$sockHosts ) )
 
-        ## Patch Markus Schmidberger (Mail 11/25/2008).
-        setOption( "cluster", try( makeNWScluster(
-                                   .sfOption$sockHosts[1:.sfOption$nodes],
-                                   type = "NWS",
-                                   outfile = tmp
-                                 ) ) )
-    }
+    ##     ## Patch Markus Schmidberger (Mail 11/25/2008).
+    ##     setOption( "cluster", try( makeNWScluster(
+    ##                                .sfOption$sockHosts[1:.sfOption$nodes],
+    ##                                type = "NWS",
+    ##                                outfile = tmp
+    ##                              ) ) )
+    ## }
     # MPI cluster (also default for irregular type).
     else {
       ## 1.81: useRScript must be FALSE. Else sfCluster wont work
@@ -335,7 +335,7 @@ sfInit <- function( parallel=NULL,
       ## Remove starting message.
       sfRemove( ".startMsg" )
     }
-    ## @TODO Checken, ob dieser Export wirklich noch bentigt ist (jan 10)
+    ## @TODO Checken, ob dieser Export wirklich noch benötigt ist (jan 10)
     else
       sfExport( ".sfOption", local=FALSE, namespace="snowfall" )
   }
